import os,sys,io
import PySimpleGUI as sg
import websocket
import threading
import requests
import json
from PIL import Image

APP_NAME = "ReSpotGUI"
RESPOT_BASE_URL="http://localhost:24879"
global window

class WsThread(threading.Thread):
    def __init__(self,window):
        super().__init__()
        self.daemon = True
        self.ws = websocket.WebSocketApp("ws://localhost:24879/events",
                                on_message=self.on_message)

        self.window = window

    def run(self):
        self.ws.run_forever()

    def on_message(self,ws,msg):
        jst = json.loads(msg)
        #print(json.dumps(jst,indent=4))
        event = jst['event']
        if event == 'metadataAvailable':
            track = jst['track']
            songname = track['name']
            artist = track['artist'][0]
            artistname = artist['name']
            title = f"{artistname} - {songname}"
            self.window['-OUTPUT-'].update(title)
            self.window.set_title(f"{APP_NAME} => {title}")
            album = track['album']
            album_name = album['name']
            album_image = album['coverGroup']['image'][1]
            album_image_token = album_image['fileId']
            album_image_url = 'http://i.scdn.co/image/'+ album_image_token.lower()
            #print("Album image url: " + album_image_url)
            jpgbytes = requests.get(album_image_url).content
            pngbytes = io.BytesIO()
            try:
                Image.open(io.BytesIO(jpgbytes)).save(pngbytes,format='PNG')
                #open(album_name+'.png','wb').write(pngbytes.getvalue())
                self.window['-ICON-'].update(data=pngbytes.getvalue())
            except BaseException as e:
                print("Error: " + str(e))
                pass
            #self.window.refresh()


    def get_ws(self):
        return self.ws



def main():

    column_layout = [
        [sg.Text("Currently Playing")],
        [sg.Text(size=(40, 1), key='-OUTPUT-')] ,
        [ sg.Button('<'),sg.Button('||'),sg.Button('>'), sg.Button('dismiss')]
    ]
    # Define the window's contents
    layout = [  
                [sg.Image('respot/no-music.png',key='-ICON-'),sg.Column(column_layout)] 
    ]

    # Create the window
    window = sg.Window(APP_NAME, layout)

    thread = WsThread(window)

    thread.start()

    while True:                               
    # Display and interact with the Window
        event, values = window.read() 
        if event == '<':
            r = requests.post(RESPOT_BASE_URL + '/player/prev')
        elif event == '>':
            r = requests.post(RESPOT_BASE_URL + '/player/next')
        elif event == '||':
            r = requests.post(RESPOT_BASE_URL + '/player/play-pause')

        elif event == sg.WIN_CLOSED or event == 'dismiss': # if user closes window or clicks cancel
            break
    window.close()
    thread.get_ws().close()
    thread.join()                               
    

if __name__ == "__main__":
    main()



import subprocess
import os,sys
import setuptools
import versioneer


def increment_version(current_version):
    version = current_version.split('.')
    version[-1] = str(int(version[-1]) + 1)
    return '.'.join(version)

def get_version():
    try:
        with open('VERSION', 'r') as f:
            version = f.read().strip()
    except FileNotFoundError:
        version = '0.0.0'
    return version

def store_version(last_version):
    with open('VERSION', 'w') as f:
        f.write(last_version)

if __name__ == '__main__':

    current_directory = os.path.dirname(os.path.abspath(__file__))
    try:
        with open(os.path.join(current_directory, 'README.md'), encoding='utf-8') as f:
            long_description = f.read()
    except Exception:
        long_description = ''
    """ 
    cur_version = get_version()
    new_version = increment_version(cur_version)
    store_version(new_version)
    """
    setuptools.setup(
        name='respotgui',
        version='0.1.28',
#        version=open('VERSION','r').read().strip(),
#        version=versioneer.get_version(),
#        cmdclass=versioneer.get_cmdclass(),
        author="digfish",
        author_email="digfish@digfish.org",
        description=(
            "A frontend for the respot-java Spotify client"
        ),
        long_description=long_description,
        long_description_content_type='text/markdown',
        license="Apache License 2.0",
        url="https://github.com/digfish/respogui",
        packages=setuptools.find_packages(),
        classifiers=[
            "Development Status :: 2 - Pre-Alpha",
            "Environment :: Win32 (MS Windows)",
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: Apache Software License",
            "Operating System :: Microsoft :: Windows",
        ],
        entry_points={
            'console_scripts': [
                'respotgui=respot:main'
            ],
            'gui_scripts': [
                'respotgui=respot:main'
            ]
        },
        package_data={'.':['./*']},
        install_requires=['PySimpleGUI', 'websocket-client', 'requests', 'Pillow'],
        include_package_data=True
    )
